==> opennebula-6.99.85-1-amd64.tar.gz: opennebula-6.99.85/src/fireedge/src/client/assets/languages/ru.js <==
lang="ru"
locale={
  "":"",
  "BackupJob":"",
  "Identifier":"",
  "Total updated VMs":"",
  "Total outdated VMs":"",
  "Total error VMs":"",
  "Created":"",
  "Auth Driver":"",
  "Started":"",
  "Affined Roles":"",
  "finalWord":"",
  "Export":"",
  "Start Date":"",
  "EndDate":"",
  "Unit memory":"",
  "PROTOCOL":"",
  "RULE_TYPE":"",
  "RANGE":"",
  "network":"network",
  "Advanced Parameters":"",
  "Elasticity Policies":"",
  "Scheduled Policies":"",
  "TIMEFORMAT":"",
  "Time Expression":"",
  "Time Format":"",
  "Select":"",
  "NIC Alias":"",
  "Rows per page":"",
  "RDP":"RDP",
  "Select a VM Template":"",
  "Role Configuration":"",
  "Enter a name for this role":"",
  "Select a network for this role":"",
  "Role Elasticity":"",
  "Adjustment type":"",
  "Positive or negative adjustment":"",
  "Role Details":"",
  "Role Name":"",
  "Configured NICs":"",
  "Add NIC":"",
  "Add a NIC to Start Configuring":"",
  "Show mandatory only":"",
  "in":"",
  "Warning before":"",
  "WARNING_PERIOD":"",
  "Potential Use Cases":"",
  "Add Group":"",
  "Affined Groups":"",
  "Host Affinity":"",
  "Affined Hosts":"",
  "VM Group Configuration":"",
  "New Role":"",
  "Show all owned by the user or his groups":"",
  "Show all owned by the user":"",
  "Divide Window":"",
  "Low":"",
  "Medium":"",
  "High":"",
  "tooltipTitle":"",
  "Non Persistent":"",
  "Menu":"",
  "Show columns":"",
  "Manage columns":"",
  "Hide column":"",
  "Unsort":"",
  "Sort by ASC":"",
  "Sort by DESC":"",
  "Sort":"",
  "Previous":"",
  "of":"",
  "Download Default Image":"",
  "value":"",
  "Group By":"",
  "Chart Type":"",
  "Line Chart":"",
  "Bar Chart":"",
  "Area Chart":"",
  "Table Chart":"",
  "Free Memory":"",
  "How to use Quota Controls":"",
  "enter Resource IDs over which this quota will apply":"",
  "this further qualifies the quota type to a more specific attribute":"",
  "Resource IDs":"",
  "Select or type a Resource ID":"",
  "VM Quota":"",
  "Datastore Quota":"",
  "Network Quota":"",
  "Image Quota":"",
  "Quota Controls":"",
  "Severity":"",
  "All Severities":"",
  "Asc":"",
  "Desc":"",
  "Attachments":"",
  "Add comment to close the ticket":"",
  "Edit Public SSH Key":"",
  "Edit Private SSH Key":"",
  "Edit SSH Key Passphrase":"",
  "Save Changes":"",
  "Secondary":"",
  "Net RX":"Net RX",
  "Net TX":"Net TX",
  "Wrong username or password":"",
  "Succesfully changed password":"",
  "Scan this Qr":"",
  "Clear error messages and warnings from selects Virtual Machines":"",
  "Daily":"",
  "VMRC":"VMRC",
  "No labels":"",
  "Sort by":"",
  "Retry":"",
  "col":"col",
  "Enter Verification Code":"",
  "Register authentication App":"",
  "Or":"",
  "Get an account":"",
  "Commercial Support":"",
  "Additional Help Resources":"",
  "Commercial Support Requests":"",
}

==> opennebula-7.0.1-1-amd64.tar.gz: opennebula-7.0.1/src/fireedge/src/client/assets/languages/ru.js <==
lang="ru"
locale={
  "":"",
  "repeat":"",
  "end":"",
  "Total updated VMs":"",
  "Total outdated VMs":"",
  "Total error VMs":"",
  "Auth Driver":"",
  "Started":"",
  "Affined Roles":"",
  "finalWord":"",
  "Export":"",
  "Start Date":"",
  "EndDate":"",
  "Unit memory":"",
  "PROTOCOL":"",
  "RULE_TYPE":"",
  "RANGE":"",
  "network":"network",
  "format":"",
  "Time Format":"",
  "Time Expression":"",
  "in":"",
  "Warning before":"",
  "WARNING_PERIOD":"",
  "PERIOD":"",
  "Potential Use Cases":"",
  "Add Group":"",
  "Affined Groups":"",
  "Host Affinity":"",
  "Rows per page":"",
  "Role Configuration":"",
  "Enter a name for this role":"",
  "Affined Hosts":"",
  "VM Group Configuration":"",
  "New Role":"",
  "Role Details":"",
  "Role Name":"",
  "Loaded":"",
  "Configured NICs":"",
  "Add NIC":"",
  "Add a NIC to Start Configuring":"",
  "Show mandatory only":"",
  "Show all owned by the user or his groups":"",
  "Show all owned by the user":"",
  "Low":"",
  "Medium":"",
  "High":"",
  "tooltipTitle":"",
  "Non Persistent":"",
  "Menu":"",
  "Show columns":"",
  "Manage columns":"",
  "Hide column":"",
  "Unsort":"",
  "Sort by ASC":"",
  "Sort by DESC":"",
  "Sort":"",
  "Card View":"",
  "List View":"",
  "Number of rows per page":"",
  "of":"",
  "Download Default Image":"",
  "value":"",
  "Group By":"",
  "Chart Type":"",
  "Line Chart":"",
  "Bar Chart":"",
  "Area Chart":"",
  "Table Chart":"",
  "How to use Quota Controls":"",
  "enter Resource IDs over which this quota will apply":"",
  "this further qualifies the quota type to a more specific attribute":"",
  "VM Quota":"",
  "Datastore Quota":"",
  "Network Quota":"",
  "Image Quota":"",
  "Quota Controls":"",
  "Severity":"",
  "All Severities":"",
  "Asc":"",
  "Desc":"",
  "Attachments":"",
  "Add comment to close the ticket":"",
  "Edit Public SSH Key":"",
  "Edit Private SSH Key":"",
  "Edit SSH Key Passphrase":"",
  "Wrong username or password":"",
  "Succesfully changed password":"",
  "Scan this Qr":"",
  "Clear error messages and warnings from selects Virtual Machines":"",
  "No labels":"",
  "Filter by label":"",
  "Sort by":"",
  "Retry":"",
  "col":"col",
  "My Dashboard":"",
  "Sign In Now":"",
  "Enter Verification Code":"",
  "Or":"",
  "Get an account":"",
  "Commercial Support":"",
  "Additional Help Resources":"",
  "Commercial Support Requests":"",
}
